parsedatetime.tests

Package parsedatetime :: Package tests |
[hide private]
[frames] | no frames]

# Source Code for Package parsedatetime.tests

     1  """
     2  Unit tests for parsedatetime
     3
     4  The tests can be run as a C{suite} by running::
     5
     6      python run_tests.py parsedatetime
     7  """
     8
     9  license = """
    10  Copyright (c) 2004-2007 Mike Taylor
    11  Copyright (c) 2006-2007 Darshana Chhajed
    12  All rights reserved.
    13
    14  Licensed under the Apache License, Version 2.0 (the "License");
    15  you may not use this file except in compliance with the License.
    16  You may obtain a copy of the License at
    17
    18     http://www.apache.org/licenses/LICENSE-2.0
    19
    20  Unless required by applicable law or agreed to in writing, software
    21  distributed under the License is distributed on an "AS IS" BASIS,
    22  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    23  See the License for the specific language governing permissions and
    24  limitations under the License.
    25  """
    26